package data_manage

import (
	"eta_gn/eta_chart_lib/global"
	"fmt"
	"strings"
	"time"
)

// ChartInfoCorrelation 相关性图表-扩展信息
//
//	type ChartInfoCorrelation struct {
//		CorrelationChartInfoId int       `orm:"column(correlation_chart_info_id);pk" description:"相关性图表ID(chart_info表source=3的)"`
//		LeadValue              int       `description:"领先值"`
//		LeadUnit               string    `description:"领先单位"`
//		CalculateValue         int       `description:"计算窗口"`
//		CalculateUnit          string    `description:"计算频度"`
//		BaseCalculateValue     int       `description:"基础计算窗口（滚动相关性的时候用到）"`
//		BaseCalculateUnit      string    `description:"基础计算频度（滚动相关性的时候用到）"`
//		DateType               int       `description:"日期类型:1:00年至今,2:10年至今,3:15年至今，4：年初至今，5:自定义时间,6:起始日期至今"`
//		StartDate              time.Time `description:"开始日期"`
//		EndDate                time.Time `description:"结束日期"`
//		EdbInfoIdFirst         int       `description:"A指标ID"`
//		EdbInfoIdSecond        int       `description:"B指标ID"`
//		PeriodData             string    `description:"X轴-期数数据"`
//		CorrelationData        string    `description:"Y轴-相关性系数"`
//		CreateTime             time.Time `description:"创建时间"`
//		ModifyTime             time.Time `description:"更新时间"`
//		AnalysisMode           int       `description:"分析模式: 0-单因子; 1-多因子"`
//	}
type ChartInfoCorrelation struct {
	CorrelationChartInfoId int       `gorm:"column:correlation_chart_info_id;primaryKey" description:"相关性图表ID(chart_info表source=3的)" orm:"column(correlation_chart_info_id);pk"`
	LeadValue              int       `gorm:"column:lead_value" description:"领先值"`
	LeadUnit               string    `gorm:"column:lead_unit" description:"领先单位"`
	CalculateValue         int       `gorm:"column:calculate_value" description:"计算窗口"`
	CalculateUnit          string    `gorm:"column:calculate_unit" description:"计算频度"`
	BaseCalculateValue     int       `gorm:"column:base_calculate_value" description:"基础计算窗口（滚动相关性的时候用到）"`
	BaseCalculateUnit      string    `gorm:"column:base_calculate_unit" description:"基础计算频度（滚动相关性的时候用到）"`
	DateType               int       `gorm:"column:date_type" description:"日期类型:1:00年至今,2:10年至今,3:15年至今，4：年初至今，5:自定义时间,6:起始日期至今"`
	StartDate              time.Time `gorm:"column:start_date" description:"开始日期"`
	EndDate                time.Time `gorm:"column:end_date" description:"结束日期"`
	EdbInfoIdFirst         int       `gorm:"column:edb_info_id_first" description:"A指标ID"`
	EdbInfoIdSecond        int       `gorm:"column:edb_info_id_second" description:"B指标ID"`
	PeriodData             string    `gorm:"column:period_data" description:"X轴-期数数据"`
	CorrelationData        string    `gorm:"column:correlation_data" description:"Y轴-相关性系数"`
	CreateTime             time.Time `gorm:"column:create_time" description:"创建时间"`
	ModifyTime             time.Time `gorm:"column:modify_time" description:"更新时间"`
	AnalysisMode           int       `gorm:"column:analysis_mode" description:"分析模式: 0-单因子; 1-多因子"`
}

func (m *ChartInfoCorrelation) TableName() string {
	return "chart_info_correlation"
}

func (m *ChartInfoCorrelation) Create() (err error) {
	o := global.DmSQL["data"]
	err = o.Create(m).Error
	if err != nil {
		return
	}
	//m.CorrelationChartInfoId = int(id)
	return
}

func (m *ChartInfoCorrelation) Update(cols []string) (err error) {
	o := global.DmSQL["data"]
	err = o.Model(m).Select(cols).Updates(m).Error
	return
}

func (m *ChartInfoCorrelation) Delete() (err error) {
	o := global.DmSQL["data"]
	sql := fmt.Sprintf(`DELETE FROM %s WHERE correlation_chart_info_id = ? LIMIT 1`, m.TableName())
	err = o.Exec(sql, m.CorrelationChartInfoId).Error
	return
}

func (m *ChartInfoCorrelation) GetItemById(id int) (err error) {
	o := global.DmSQL["data"]
	sql := fmt.Sprintf(`SELECT * FROM %s WHERE correlation_chart_info_id = ? LIMIT 1`, m.TableName())
	err = o.Raw(sql, id).First(&m).Error
	return
}

func (m *ChartInfoCorrelation) GetItemByCondition(condition string, pars []interface{}) (err error) {
	o := global.DmSQL["data"]
	sql := fmt.Sprintf(`SELECT * FROM %s WHERE 1=1 %s `, m.TableName(), condition)
	err = o.Raw(sql, pars).First(&m).Error
	return
}

func (m *ChartInfoCorrelation) GetItemsByCondition(condition string, pars []interface{}, fieldArr []string, orderRule string) (items []*ChartInfoCorrelation, err error) {
	o := global.DmSQL["data"]
	fields := strings.Join(fieldArr, ",")
	if len(fieldArr) == 0 {
		fields = `*`
	}
	order := ``
	if orderRule != "" {
		order = ` ORDER BY ` + orderRule
	}
	sql := fmt.Sprintf(`SELECT %s FROM %s WHERE 1=1 %s %s`, fields, m.TableName(), condition, order)
	err = o.Raw(sql, pars).Scan(&items).Error
	return
}

// func (m *ChartInfoCorrelation) Create() (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	_, err = o.Insert(m)
// 	if err != nil {
// 		return
// 	}
// 	//m.CorrelationChartInfoId = int(id)
// 	return
// }

// func (m *ChartInfoCorrelation) Update(cols []string) (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	_, err = o.Update(m, cols...)
// 	return
// }

// func (m *ChartInfoCorrelation) Delete() (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := fmt.Sprintf(`DELETE FROM %s WHERE correlation_chart_info_id = ? LIMIT 1`, m.TableName())
// 	_, err = o.Raw(sql, m.CorrelationChartInfoId).Exec()
// 	return
// }

// func (m *ChartInfoCorrelation) GetItemById(id int) (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := fmt.Sprintf(`SELECT * FROM %s WHERE correlation_chart_info_id = ? LIMIT 1`, m.TableName())
// 	err = o.Raw(sql, id).QueryRow(&m)
// 	return
// }

// func (m *ChartInfoCorrelation) GetItemByCondition(condition string, pars []interface{}) (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := fmt.Sprintf(`SELECT * FROM %s WHERE 1=1 %s LIMIT 1`, m.TableName(), condition)
// 	err = o.Raw(sql, pars).QueryRow(&m)
// 	return
// }

// func (m *ChartInfoCorrelation) GetItemsByCondition(condition string, pars []interface{}, fieldArr []string, orderRule string) (items []*ChartInfoCorrelation, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	fields := strings.Join(fieldArr, ",")
// 	if len(fieldArr) == 0 {
// 		fields = `*`
// 	}
// 	order := ``
// 	if orderRule != "" {
// 		order = ` ORDER BY ` + orderRule
// 	}
// 	sql := fmt.Sprintf(`SELECT %s FROM %s WHERE 1=1 %s %s`, fields, m.TableName(), condition, order)
// 	_, err = o.Raw(sql, pars).QueryRows(&items)
// 	return
// }

// FactorCorrelationConfig 因子指标系列-相关性配置
//
//	type FactorCorrelationConfig struct {
//		LeadValue      int                       `description:"领先期数"`
//		LeadUnit       string                    `description:"频度"`
//		CalculateValue int                       `description:"计算窗口"`
//		CalculateUnit  string                    `description:"计算频度"`
//		SeriesEdb      []CorrelationSeriesEdbReq `description:"关联系列指标"`
//	}
type FactorCorrelationConfig struct {
	LeadValue      int                       `gorm:"column:lead_value" description:"领先期数"`
	LeadUnit       string                    `gorm:"column:lead_unit" description:"频度"`
	CalculateValue int                       `gorm:"column:calculate_value" description:"计算窗口"`
	CalculateUnit  string                    `gorm:"column:calculate_unit" description:"计算频度"`
	SeriesEdb      []CorrelationSeriesEdbReq `gorm:"column:series_edb" description:"关联系列指标"`
}

// CorrelationChartLegend 相关性图表图例
type CorrelationChartLegend struct {
	LegendName string `description:"图例名称"`
	Color      string `description:"图例颜色"`
	EdbInfoId  int    `description:"指标ID"`
	SeriesId   int    `description:"因子指标系列ID"`
}

// CorrelationSeriesEdbReq 指标系列
type CorrelationSeriesEdbReq struct {
	EdbInfoId int `description:"指标ID"`
	SeriesId  int `description:"因子指标系列ID"`
}

// CorrelationChartInfoExtraConfig 相关性图表额外设置
type CorrelationChartInfoExtraConfig struct {
	LegendConfig []*CorrelationChartLegend `description:"图例设置"`
}
