package excel

import (
	"eta_gn/eta_chart_lib/global"
	"time"
)

// ExcelSheet excel表格详情表
//
//	type ExcelSheet struct {
//		ExcelSheetId int       `orm:"column(excel_sheet_id);pk"`
//		ExcelInfoId  int       `description:"excel的id"`
//		SheetName    string    `description:"sheet名称"`
//		PageNum      int       `description:"总页码数"`
//		Index        string    `description:"excel数据中的index"`
//		Sort         int       `description:"排序"`
//		Config       string    `description:"配置信息"`
//		CalcChain    string    `description:"计算公式"`
//		ModifyTime   time.Time `description:"最近修改日期"`
//		CreateTime   time.Time `description:"创建日期"`
//	}
//
// ExcelSheet excel表格详情表
type ExcelSheet struct {
	ExcelSheetId int       `gorm:"column:excel_sheet_id;primaryKey" orm:"column(excel_sheet_id);pk"`
	ExcelInfoId  int       `gorm:"column:excel_info_id" description:"excel的id"`
	SheetName    string    `gorm:"column:sheet_name" description:"sheet名称"`
	PageNum      int       `gorm:"column:page_num" description:"总页码数"`
	Index        string    `gorm:"column:index" description:"excel数据中的index"`
	Sort         int       `gorm:"column:sort" description:"排序"`
	Config       string    `gorm:"column:config" description:"配置信息"`
	CalcChain    string    `gorm:"column:calc_chain" description:"计算公式"`
	ModifyTime   time.Time `gorm:"column:modify_time" description:"最近修改日期"`
	CreateTime   time.Time `gorm:"column:create_time" description:"创建日期"`
}

// Update 更新 excel表格的sheet基础信息
func (excelSheet *ExcelSheet) Update(cols []string) (err error) {
	o := global.DmSQL["data"]
	err = o.Model(excelSheet).Select(cols).Updates(excelSheet).Error

	return
}

// AddExcelSheet 新增excel表格的sheet基础信息
func AddExcelSheet(excelInfo *ExcelSheet) (err error) {
	o := global.DmSQL["data"]
	// 表格信息入库
	err = o.Create(excelInfo).Error
	return
}

// GetAllSheetList 根据excel_id获取所有的sheet
func GetAllSheetList(excelInfoId int) (item []*ExcelSheet, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT *
FROM excel_sheet WHERE 1=1 AND excel_info_id = ? `
	sql += " ORDER BY sort asc "
	err = o.Raw(sql, excelInfoId).Scan(&item).Error
	return
}

// Update 更新 excel表格的sheet基础信息
// func (excelSheet *ExcelSheet) Update(cols []string) (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	_, err = o.Update(excelSheet, cols...)

// 	return
// }

// // AddExcelSheet 新增excel表格的sheet基础信息
// func AddExcelSheet(excelInfo *ExcelSheet) (err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	// 表格信息入库
// 	lastId, err := o.Insert(excelInfo)
// 	if err != nil {
// 		return
// 	}
// 	excelInfo.ExcelInfoId = int(lastId)

// 	return
// }

// // GetAllSheetList 根据excel_id获取所有的sheet
// func GetAllSheetList(excelInfoId int) (item []*ExcelSheet, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := ` SELECT *
// FROM excel_sheet WHERE 1=1 AND excel_info_id = ? `
// 	sql += " ORDER BY sort asc "
// 	_, err = o.Raw(sql, excelInfoId).QueryRows(&item)
// 	return
// }

// SheetItem excel表格详情表
//
//	type SheetItem struct {
//		ExcelSheetId int             `orm:"column(excel_sheet_id);pk" json:"-"`
//		ExcelInfoId  int             `description:"excel的id"  json:"-"`
//		SheetName    string          `description:"sheet名称"`
//		PageNum      int             `description:"数据总页码数"`
//		Index        string          `description:"excel数据中的index"`
//		Sort         int             `description:"排序"`
//		Config       string          `description:"sheet配置"`
//		CalcChain    string          `description:"计算公式"`
//		ModifyTime   time.Time       `description:"最近修改日期" json:"-"`
//		CreateTime   time.Time       `description:"创建日期"`
//		Data         *ExcelSheetData `description:"excel的数据"`
//	}
type SheetItem struct {
	ExcelSheetId int             `gorm:"column:excel_sheet_id;primaryKey" json:"-" orm:"column(excel_sheet_id);pk"`
	ExcelInfoId  int             `gorm:"column:excel_info_id" description:"excel的id" json:"-"`
	SheetName    string          `gorm:"column:sheet_name" description:"sheet名称" `
	PageNum      int             `gorm:"column:page_num" description:"数据总页码数" `
	Index        string          `gorm:"column:index" description:"excel数据中的index" `
	Sort         int             `gorm:"column:sort" description:"排序" `
	Config       string          `gorm:"column:config" description:"sheet配置" `
	CalcChain    string          `gorm:"column:calc_chain" description:"计算公式"`
	ModifyTime   time.Time       `gorm:"column:modify_time" description:"最近修改日期" json:"-"`
	CreateTime   time.Time       `gorm:"column:create_time" description:"创建日期"`
	Data         *ExcelSheetData `description:"excel的数据"`
}

// GetAllSheetItemList 根据excel_id获取所有的sheet详情
func GetAllSheetItemList(excelInfoId int) (item []*SheetItem, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT *
FROM excel_sheet WHERE 1=1 AND excel_info_id = ? `
	sql += " ORDER BY sort asc "
	err = o.Raw(sql, excelInfoId).Scan(&item).Error
	return
}

// GetAllNoConfigSheetItemList 根据excel_id获取所有的sheet详情
func GetAllNoConfigSheetItemList(excelInfoId int) (item []*SheetItem, err error) {
	o := global.DmSQL["data"]
	sql := ` SELECT excel_sheet_id,excel_info_id,sheet_name,sort,page_num,create_time
FROM excel_sheet WHERE 1=1 AND excel_info_id = ? `
	sql += " ORDER BY sort asc "
	err = o.Raw(sql, excelInfoId).Scan(&item).Error
	return
}

// AddExcelSheetParams excel表格详情表
//
//	type AddExcelSheetParams struct {
//		ExcelSheetId int               `orm:"column(excel_sheet_id);pk"`
//		ExcelInfoId  int               `description:"excel的id"`
//		SheetName    string            `description:"sheet名称"`
//		Index        string            `description:"excel数据中的index"`
//		Sort         int               `description:"排序"`
//		Config       string            `description:"配置信息"`
//		CalcChain    string            `description:"计算公式"`
//		DataList     []*ExcelSheetData `description:"excel的数据"`
//	}

// AddExcelSheetParams excel表格详情表
type AddExcelSheetParams struct {
	ExcelSheetId int               `gorm:"column:excel_sheet_id;primaryKey" orm:"column(excel_sheet_id);pk"`
	ExcelInfoId  int               `gorm:"column:excel_info_id" description:"excel的id" `
	SheetName    string            `gorm:"column:sheet_name" description:"sheet名称" `
	Index        string            `gorm:"column:index" description:"excel数据中的index" `
	Sort         int               `gorm:"column:sort" description:"排序" `
	Config       string            `gorm:"column:config" description:"配置信息" `
	CalcChain    string            `gorm:"column:calc_chain" description:"计算公式" `
	DataList     []*ExcelSheetData `gorm:"column:data_list" description:"excel的数据" `
}
