package future_good

import (
	"eta_gn/eta_chart_lib/global"
	"eta_gn/eta_chart_lib/utils"
	"time"

	"github.com/rdlucklib/rdluck_tools/paging"
)

// FutureGoodEdbData 期货指标数据的表
//
//	type FutureGoodEdbData struct {
//		FutureGoodEdbDataId int       `orm:"column(future_good_edb_data_id);pk"`
//		FutureGoodEdbInfoId int       `description:"期货指标id"`
//		FutureGoodEdbCode   string    `description:"期货指标code"`
//		DataTime            time.Time `description:"数据日期"`
//		TradeCode           string    `description:"证券代码"`
//		Open                float64   `description:"开盘价"`
//		High                float64   `description:"最高价"`
//		Low                 float64   `description:"最低价"`
//		Close               float64   `description:"收盘价"`
//		Volume              float64   `description:"成交量"`
//		Amt                 float64   `description:"成交额"`
//		Oi                  float64   `description:"持仓量"`
//		Settle              float64   `description:"结算价"`
//		DataTimestamp       int64     `description:"数据日期时间戳"`
//		ModifyTime          time.Time
//		CreateTime          time.Time
//	}

// FutureGoodEdbData 期货指标数据的表
type FutureGoodEdbData struct {
	FutureGoodEdbDataId int       `gorm:"column:future_good_edb_data_id;primaryKey" description:"期货指标数据ID" orm:"column(future_good_edb_data_id);pk"`
	FutureGoodEdbInfoId int       `gorm:"column:future_good_edb_info_id" description:"期货指标id"`
	FutureGoodEdbCode   string    `gorm:"column:future_good_edb_code" description:"期货指标code"`
	DataTime            time.Time `gorm:"column:data_time" description:"数据日期"`
	TradeCode           string    `gorm:"column:trade_code" description:"证券代码"`
	Open                float64   `gorm:"column:open" description:"开盘价"`
	High                float64   `gorm:"column:high" description:"最高价"`
	Low                 float64   `gorm:"column:low" description:"最低价"`
	Close               float64   `gorm:"column:close" description:"收盘价"`
	Volume              float64   `gorm:"column:volume" description:"成交量"`
	Amt                 float64   `gorm:"column:amt" description:"成交额"`
	Oi                  float64   `gorm:"column:oi" description:"持仓量"`
	Settle              float64   `gorm:"column:settle" description:"结算价"`
	DataTimestamp       int64     `gorm:"column:data_timestamp" description:"数据日期时间戳"`
	ModifyTime          time.Time `gorm:"column:modify_time" description:"修改时间"`
	CreateTime          time.Time `gorm:"column:create_time" description:"创建时间"`
}

// FutureGoodEdbDataListResp 期货指标数据列表数据返回
type FutureGoodEdbDataListResp struct {
	Paging *paging.PagingItem
	List   []*FutureGoodEdbDataItem
}

// FutureGoodEdbDataItem 期货指标数据列表数据
//
//	type FutureGoodEdbDataItem struct {
//		FutureGoodEdbDataId int     `orm:"column(future_good_edb_data_id);pk"`
//		FutureGoodEdbInfoId int     `description:"期货指标id"`
//		FutureGoodEdbCode   string  `description:"期货指标code"`
//		FutureGoodEdbName   string  `description:"期货指标名称"`
//		DataTime            string  `description:"数据日期"`
//		TradeCode           string  `description:"证券代码"`
//		Open                float64 `description:"开盘价"`
//		High                float64 `description:"最高价"`
//		Low                 float64 `description:"最低价"`
//		Close               float64 `description:"收盘价"`
//		Volume              float64 `description:"成交量"`
//		Amt                 float64 `description:"成交额"`
//		Oi                  float64 `description:"持仓量"`
//		Settle              float64 `description:"结算价"`
//		DataTimestamp       int64   `description:"数据日期时间戳"`
//		ModifyTime          string
//		CreateTime          string
//	}

// FutureGoodEdbDataItem 期货指标数据列表数据
type FutureGoodEdbDataItem struct {
	FutureGoodEdbDataId int     `gorm:"column:future_good_edb_data_id;primaryKey" description:"期货指标数据ID" orm:"column(future_good_edb_data_id);pk"`
	FutureGoodEdbInfoId int     `gorm:"column:future_good_edb_info_id" description:"期货指标id"`
	FutureGoodEdbCode   string  `gorm:"column:future_good_edb_code" description:"期货指标code"`
	FutureGoodEdbName   string  `gorm:"column:future_good_edb_name" description:"期货指标名称"`
	DataTime            string  `gorm:"column:data_time" description:"数据日期"`
	TradeCode           string  `gorm:"column:trade_code" description:"证券代码"`
	Open                float64 `gorm:"column:open" description:"开盘价"`
	High                float64 `gorm:"column:high" description:"最高价"`
	Low                 float64 `gorm:"column:low" description:"最低价"`
	Close               float64 `gorm:"column:close" description:"收盘价"`
	Volume              float64 `gorm:"column:volume" description:"成交量"`
	Amt                 float64 `gorm:"column:amt" description:"成交额"`
	Oi                  float64 `gorm:"column:oi" description:"持仓量"`
	Settle              float64 `gorm:"column:settle" description:"结算价"`
	DataTimestamp       int64   `gorm:"column:data_timestamp" description:"数据日期时间戳"`
	ModifyTime          string  `gorm:"column:modify_time" description:"修改时间"`
	CreateTime          string  `gorm:"column:create_time" description:"创建时间"`
}

// GetFutureGoodEdbDataListCount 获取期货指标数据汇总数
func GetFutureGoodEdbDataListCount(condition string, pars []interface{}) (count int, err error) {
	o := global.DmSQL["data"]
	sql := `SELECT COUNT(1) AS count FROM future_good_edb_data WHERE 1=1 `
	if condition != "" {
		sql += condition
	}
	err = o.Raw(sql, pars).Scan(&count).Error
	return
}

// GetFutureGoodEdbDataList 获取期货指标数据列表
func GetFutureGoodEdbDataList(condition string, pars []interface{}, startSize, pageSize int) (list []*FutureGoodEdbDataItem, err error) {
	o := global.DmSQL["data"]
	sql := `SELECT * FROM future_good_edb_data WHERE 1=1 `
	if condition != "" {
		sql += condition
	}
	sql += `ORDER BY modify_time DESC LIMIT ?,?`
	err = o.Raw(sql, pars, startSize, pageSize).Scan(&list).Error
	return
}

// GetFutureGoodEdbDataListCount 获取期货指标数据汇总数
// func GetFutureGoodEdbDataListCount(condition string, pars []interface{}) (count int, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := `SELECT COUNT(1) AS count FROM future_good_edb_data WHERE 1=1 `
// 	if condition != "" {
// 		sql += condition
// 	}
// 	err = o.Raw(sql, pars).QueryRow(&count)
// 	return
// }

// // GetFutureGoodEdbDataList 获取期货指标数据列表
// func GetFutureGoodEdbDataList(condition string, pars []interface{}, startSize, pageSize int) (list []*FutureGoodEdbDataItem, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	sql := `SELECT * FROM future_good_edb_data WHERE 1=1 `
// 	if condition != "" {
// 		sql += condition
// 	}
// 	sql += `ORDER BY modify_time DESC LIMIT ?,?`
// 	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&list)
// 	return
// }

type EdbDataList struct {
	EdbDataId     int     `description:" 指标数据ID"`
	EdbInfoId     int     `description:"指标ID"`
	DataTime      string  //`json:"-" description:"数据日期"`
	DataTimestamp int64   `description:"数据日期"`
	Value         float64 `description:"数据值"`
}

func GetFutureGoodEdbDataListByDate(futureGoodEdbInfoId int, startDate, endDate string) (list []*FutureGoodEdbData, err error) {
	var pars []interface{}
	sql := `SELECT * FROM future_good_edb_data WHERE 1=1 AND future_good_edb_info_id = ? `
	if startDate != "" {
		sql += ` AND data_time>=? `
		pars = append(pars, startDate)
	}
	if endDate != "" {
		sql += ` AND data_time<=? `
		pars = append(pars, endDate)
	}

	sql += ` ORDER BY data_time ASC `
	o := global.DmSQL["data"]
	err = o.Raw(sql, futureGoodEdbInfoId, pars).Scan(&list).Error
	return
}

func GetFutureGoodEdbDataListByIdsAndDate(futureGoodEdbInfoIds []int, startDate, endDate string) (list []*FutureGoodEdbData, err error) {
	var pars []interface{}
	sql := `SELECT * FROM future_good_edb_data WHERE 1=1 AND future_good_edb_info_id in (` + utils.GetOrmInReplace(len(futureGoodEdbInfoIds)) + `)  `
	if startDate != "" {
		sql += ` AND data_time>=? `
		pars = append(pars, startDate)
	}
	if endDate != "" {
		sql += ` AND data_time<=? `
		pars = append(pars, endDate)
	}

	sql += ` ORDER BY data_time ASC `
	o := global.DmSQL["data"]
	err = o.Raw(sql, futureGoodEdbInfoIds, pars).Scan(&list).Error
	return
}

// func GetFutureGoodEdbDataListByDate(futureGoodEdbInfoId int, startDate, endDate string) (list []*FutureGoodEdbData, err error) {
// 	var pars []interface{}
// 	sql := `SELECT * FROM future_good_edb_data WHERE 1=1 AND future_good_edb_info_id = ? `
// 	if startDate != "" {
// 		sql += ` AND data_time>=? `
// 		pars = append(pars, startDate)
// 	}
// 	if endDate != "" {
// 		sql += ` AND data_time<=? `
// 		pars = append(pars, endDate)
// 	}

// 	sql += ` ORDER BY data_time ASC `
// 	o := orm.NewOrmUsingDB("data")
// 	_, err = o.Raw(sql, futureGoodEdbInfoId, pars).QueryRows(&list)
// 	return
// }

// func GetFutureGoodEdbDataListByIdsAndDate(futureGoodEdbInfoIds []int, startDate, endDate string) (list []*FutureGoodEdbData, err error) {
// 	var pars []interface{}
// 	sql := `SELECT * FROM future_good_edb_data WHERE 1=1 AND future_good_edb_info_id in (` + utils.GetOrmInReplace(len(futureGoodEdbInfoIds)) + `)  `
// 	if startDate != "" {
// 		sql += ` AND data_time>=? `
// 		pars = append(pars, startDate)
// 	}
// 	if endDate != "" {
// 		sql += ` AND data_time<=? `
// 		pars = append(pars, endDate)
// 	}

// 	sql += ` ORDER BY data_time ASC `
// 	o := orm.NewOrmUsingDB("data")
// 	_, err = o.Raw(sql, futureGoodEdbInfoIds, pars).QueryRows(&list)
// 	return
// }
