package data_manage

import (
	"eta_gn/eta_chart_lib/global"
	"time"
)

// PredictEdbRuleData 预测指标，动态规则的计算数据
//
//	type PredictEdbRuleData struct {
//		PredictEdbRuleDataId int `orm:"column(predict_edb_rule_data_id);pk"`
//		EdbInfoId            int
//		ConfigId             int
//		DataTime             string
//		Value                float64
//		CreateTime           time.Time
//		ModifyTime           time.Time
//		DataTimestamp        int64
//	}
type PredictEdbRuleData struct {
	PredictEdbRuleDataId int       `gorm:"column:predict_edb_rule_data_id;primaryKey" description:"预测指标动态规则计算数据ID" orm:"column(predict_edb_rule_data_id);pk"`
	EdbInfoId            int       `gorm:"column:edb_info_id" description:"指标ID"`
	ConfigId             int       `gorm:"column:config_id" description:"配置ID"`
	DataTime             string    `gorm:"column:data_time" description:"数据时间"`
	Value                float64   `gorm:"column:value" description:"计算值"`
	CreateTime           time.Time `gorm:"column:create_time" description:"创建时间"`
	ModifyTime           time.Time `gorm:"column:modify_time" description:"修改时间"`
	DataTimestamp        int64     `gorm:"column:data_timestamp" description:"数据时间戳"`
}

// GetPredictEdbRuleDataList 根据基础预测指标id集合 获取 所有的普通指标列表数据
func GetPredictEdbRuleDataList(edbInfoId, configId int, startDate, endDate string) (list []*PredictEdbRuleData, err error) {
	o := global.DmSQL["data"]
	var pars []interface{}
	sql := ` SELECT * FROM predict_edb_rule_data WHERE edb_info_id = ? AND config_id = ? `
	if startDate != "" {
		sql += ` AND data_time>=? `
		pars = append(pars, startDate)
	}
	if endDate != "" {
		sql += ` AND data_time<=? `
		pars = append(pars, endDate)
	}
	sql += ` ORDER BY data_time ASC `
	err = o.Raw(sql, edbInfoId, configId, pars).Scan(&list).Error
	return
}

// func GetPredictEdbRuleDataList(edbInfoId, configId int, startDate, endDate string) (list []*PredictEdbRuleData, err error) {
// 	o := orm.NewOrmUsingDB("data")
// 	var pars []interface{}
// 	sql := ` SELECT * FROM predict_edb_rule_data WHERE edb_info_id = ? AND config_id = ? `
// 	if startDate != "" {
// 		sql += ` AND data_time>=? `
// 		pars = append(pars, startDate)
// 	}
// 	if endDate != "" {
// 		sql += ` AND data_time<=? `
// 		pars = append(pars, endDate)
// 	}
// 	sql += ` ORDER BY data_time ASC `
// 	_, err = o.Raw(sql, edbInfoId, configId, pars).QueryRows(&list)
// 	return
// }
